@@ -16,15 +16,17 @@
 # Copyright (c) OWASP Foundation. All Rights Reserved.
 
 
+from collections.abc import Generator, Iterable
 from datetime import datetime
 from itertools import chain
-from typing import TYPE_CHECKING, Generator, Iterable, Optional, Union
+from typing import TYPE_CHECKING, Optional, Union
 from uuid import UUID, uuid4
 from warnings import warn
 
-import serializable
+import py_serializable as serializable
 from sortedcontainers import SortedSet
 
+from .._internal.compare import ComparableTuple as _ComparableTuple
 from .._internal.time import get_now_utc as _get_now_utc
 from ..exception.model import LicenseExpressionAlongWithOthersException, UnknownComponentDependencyException
 from ..schema.schema import (
@@ -36,14 +38,14 @@ from ..schema.schema import (
     SchemaVersion1Dot5,
     SchemaVersion1Dot6,
 )
-from ..serialization import LicenseRepositoryHelper, UrnUuidHelper
-from . import ExternalReference, Property
+from ..serialization import UrnUuidHelper
+from . import _BOM_LINK_PREFIX, ExternalReference, Property
 from .bom_ref import BomRef
 from .component import Component
 from .contact import OrganizationalContact, OrganizationalEntity
 from .definition import Definitions
 from .dependency import Dependable, Dependency
-from .license import License, LicenseExpression, LicenseRepository
+from .license import License, LicenseExpression, LicenseRepository, _LicenseRepositorySerializationHelper
 from .lifecycle import Lifecycle, LifecycleRepository, _LifecycleRepositoryHelper
 from .service import Service
 from .tool import Tool, ToolRepository, _ToolRepositoryHelper
@@ -53,13 +55,13 @@ if TYPE_CHECKING:  # pragma: no cover
     from packageurl import PackageURL
 
 
-@serializable.serializable_class
+@serializable.serializable_class(ignore_unknown_during_deserialization=True)
 class BomMetaData:
     """
     This is our internal representation of the metadata complex type within the CycloneDX standard.
 
     .. note::
-        See the CycloneDX Schema for Bom metadata: https://cyclonedx.org/docs/1.5/#type_metadata
+        See the CycloneDX Schema for Bom metadata: https://cyclonedx.org/docs/1.6/xml/#type_metadata
     """
 
     def __init__(
@@ -77,21 +79,16 @@ class BomMetaData:
         manufacture: Optional[OrganizationalEntity] = None,
     ) -> None:
         self.timestamp = timestamp or _get_now_utc()
-        self.tools = tools or []  # type:ignore[assignment]
-        self.authors = authors or []  # type:ignore[assignment]
+        self.tools = tools or []
+        self.authors = authors or []
         self.component = component
         self.supplier = supplier
-        self.licenses = licenses or []  # type:ignore[assignment]
-        self.properties = properties or []  # type:ignore[assignment]
+        self.licenses = licenses or []
+        self.properties = properties or []
         self.manufacturer = manufacturer
-        self.lifecycles = lifecycles or []  # type:ignore[assignment]
-
+        self.lifecycles = lifecycles or []
+        # deprecated properties below
         self.manufacture = manufacture
-        if manufacture:
-            warn(
-                '`bom.metadata.manufacture` is deprecated from CycloneDX v1.6 onwards. '
-                'Please use `bom.metadata.component.manufacturer` instead.',
-                DeprecationWarning)
 
     @property
     @serializable.type_mapping(serializable.helpers.XsdDateTime)
@@ -177,7 +174,7 @@ class BomMetaData:
         return self._component
 
     @component.setter
-    def component(self, component: Component) -> None:
+    def component(self, component: Optional[Component]) -> None:
         """
         The (optional) component that the BOM describes.
 
@@ -212,6 +209,11 @@ class BomMetaData:
         @todo Based on https://github.com/CycloneDX/specification/issues/346,
               we should set this data on `.component.manufacturer`.
         """
+        if manufacture is not None:
+            warn(
+                '`bom.metadata.manufacture` is deprecated from CycloneDX v1.6 onwards. '
+                'Please use `bom.metadata.component.manufacturer` instead.',
+                DeprecationWarning)
         self._manufacture = manufacture
 
     @property
@@ -254,7 +256,7 @@ class BomMetaData:
     @serializable.view(SchemaVersion1Dot4)
     @serializable.view(SchemaVersion1Dot5)
     @serializable.view(SchemaVersion1Dot6)
-    @serializable.type_mapping(LicenseRepositoryHelper)
+    @serializable.type_mapping(_LicenseRepositorySerializationHelper)
     @serializable.xml_sequence(9)
     def licenses(self) -> LicenseRepository:
         """
@@ -293,22 +295,31 @@ class BomMetaData:
     def properties(self, properties: Iterable[Property]) -> None:
         self._properties = SortedSet(properties)
 
+    def __comparable_tuple(self) -> _ComparableTuple:
+        return _ComparableTuple((
+            _ComparableTuple(self.authors), self.component, _ComparableTuple(self.licenses), self.manufacture,
+            _ComparableTuple(self.properties),
+            _ComparableTuple(self.lifecycles), self.supplier, self.timestamp, self.tools, self.manufacturer
+        ))
+
     def __eq__(self, other: object) -> bool:
         if isinstance(other, BomMetaData):
-            return hash(other) == hash(self)
+            return self.__comparable_tuple() == other.__comparable_tuple()
         return False
 
     def __hash__(self) -> int:
-        return hash((
-            tuple(self.authors), self.component, tuple(self.licenses), self.manufacture, tuple(self.properties),
-            tuple(self.lifecycles), self.supplier, self.timestamp, self.tools, self.manufacturer
-        ))
+        return hash(self.__comparable_tuple())
 
     def __repr__(self) -> str:
         return f'<BomMetaData timestamp={self.timestamp}, component={self.component}>'
 
 
-@serializable.serializable_class(ignore_during_deserialization=['$schema', 'bom_format', 'spec_version'])
+@serializable.serializable_class(
+    ignore_during_deserialization={
+        '$schema', 'bom_format', 'spec_version',  # JSON-implementation's format hints
+    },
+    ignore_unknown_during_deserialization=True
+)
 class Bom:
     """
     This is our internal representation of a bill-of-materials (BOM).
@@ -339,12 +350,12 @@ class Bom:
         self.serial_number = serial_number or uuid4()
         self.version = version
         self.metadata = metadata or BomMetaData()
-        self.components = components or []  # type:ignore[assignment]
-        self.services = services or []  # type:ignore[assignment]
-        self.external_references = external_references or []  # type:ignore[assignment]
-        self.vulnerabilities = vulnerabilities or []  # type:ignore[assignment]
-        self.dependencies = dependencies or []  # type:ignore[assignment]
-        self.properties = properties or []  # type:ignore[assignment]
+        self.components = components or []
+        self.services = services or []
+        self.external_references = external_references or []
+        self.vulnerabilities = vulnerabilities or []
+        self.dependencies = dependencies or []
+        self.properties = properties or []
         self.definitions = definitions or Definitions()
 
     @property
@@ -394,7 +405,7 @@ class Bom:
             Metadata object instance for this Bom.
 
         .. note::
-            See the CycloneDX Schema for Bom metadata: https://cyclonedx.org/docs/1.3/#type_metadata
+            See the CycloneDX Schema for Bom metadata: https://cyclonedx.org/docs/1.6/xml/#type_metadata
         """
         return self._metadata
 
@@ -563,7 +574,7 @@ class Bom:
         The repository for definitions
 
         Returns:
-            `DefinitionRepository`
+            `Definitions`
         """
         return self._definitions if len(self._definitions.standards) > 0 else None
 
@@ -663,7 +674,7 @@ class Bom:
                 self.register_dependency(target=_d2, depends_on=None)
 
     def urn(self) -> str:
-        return f'urn:cdx:{self.serial_number}/{self.version}'
+        return f'{_BOM_LINK_PREFIX}{self.serial_number}/{self.version}'
 
     def validate(self) -> bool:
         """
@@ -694,9 +705,10 @@ class Bom:
                 'One or more Components have Dependency references to Components/Services that are not known in this '
                 f'BOM. They are: {dependency_diff}')
 
-        # 2. if root component is set: dependencies should exist for the Component this BOM is describing
-        if self.metadata.component and not any(map(
-            lambda d: d.ref == self.metadata.component.bom_ref and len(d.dependencies) > 0,  # type: ignore[union-attr]
+        # 2. if root component is set and there are other components: dependencies should exist for the Component
+        # this BOM is describing
+        if self.metadata.component and len(self.components) > 0 and not any(map(
+            lambda d: d.ref == self.metadata.component.bom_ref and len(d.dependencies) > 0,  # type:ignore[union-attr]
             self.dependencies
         )):
             warn(
@@ -709,7 +721,7 @@ class Bom:
         # 3. If a LicenseExpression is set, then there must be no other license.
         # see https://github.com/CycloneDX/specification/pull/205
         elem: Union[BomMetaData, Component, Service]
-        for elem in chain(  # type: ignore[assignment]
+        for elem in chain(  # type:ignore[assignment]
             [self.metadata],
             self.metadata.component.get_all_nested_components(include_self=True) if self.metadata.component else [],
             chain.from_iterable(c.get_all_nested_components(include_self=True) for c in self.components),
@@ -721,17 +733,22 @@ class Bom:
 
         return True
 
+    def __comparable_tuple(self) -> _ComparableTuple:
+        return _ComparableTuple((
+            self.serial_number, self.version, self.metadata, _ComparableTuple(
+                self.components), _ComparableTuple(self.services),
+            _ComparableTuple(self.external_references), _ComparableTuple(
+                self.dependencies), _ComparableTuple(self.properties),
+            _ComparableTuple(self.vulnerabilities),
+        ))
+
     def __eq__(self, other: object) -> bool:
         if isinstance(other, Bom):
-            return hash(other) == hash(self)
+            return self.__comparable_tuple() == other.__comparable_tuple()
         return False
 
     def __hash__(self) -> int:
-        return hash((
-            self.serial_number, self.version, self.metadata, tuple(self.components), tuple(self.services),
-            tuple(self.external_references), tuple(self.dependencies), tuple(self.properties),
-            tuple(self.vulnerabilities),
-        ))
+        return hash(self.__comparable_tuple())
 
     def __repr__(self) -> str:
         return f'<Bom uuid={self.serial_number}, hash={hash(self)}>'
