@@ -66,7 +66,7 @@ from .license import License, LicenseRepository, _LicenseRepositorySerialization
 from .release_note import ReleaseNotes
 
 
-@serializable.serializable_class
+@serializable.serializable_class(ignore_unknown_during_deserialization=True)
 class Commit:
     """
     Our internal representation of the `commitType` complex type.
@@ -197,7 +197,7 @@ class ComponentScope(str, Enum):
     Enum object that defines the permissable 'scopes' for a Component according to the CycloneDX schema.
 
     .. note::
-        See the CycloneDX Schema definition: https://cyclonedx.org/docs/1.6/#type_scope
+        See the CycloneDX Schema definition: https://cyclonedx.org/docs/1.6/xml/#type_scope
     """
     # see `_ComponentScopeSerializationHelper.__CASES` for view/case map
     REQUIRED = 'required'
@@ -253,7 +253,7 @@ class ComponentType(str, Enum):
     Enum object that defines the permissible 'types' for a Component according to the CycloneDX schema.
 
     .. note::
-        See the CycloneDX Schema definition: https://cyclonedx.org/docs/1.6/#type_classification
+        See the CycloneDX Schema definition: https://cyclonedx.org/docs/1.6/xml/#type_classification
     """
     # see `_ComponentTypeSerializationHelper.__CASES` for view/case map
     APPLICATION = 'application'
@@ -326,7 +326,7 @@ class _ComponentTypeSerializationHelper(serializable.helpers.BaseHelper):
         return ComponentType(o)
 
 
-@serializable.serializable_class
+@serializable.serializable_class(ignore_unknown_during_deserialization=True)
 class Diff:
     """
     Our internal representation of the `diffType` complex type.
@@ -408,7 +408,7 @@ class PatchClassification(str, Enum):
     UNOFFICIAL = 'unofficial'
 
 
-@serializable.serializable_class
+@serializable.serializable_class(ignore_unknown_during_deserialization=True)
 class Patch:
     """
     Our internal representation of the `patchType` complex type.
@@ -498,7 +498,7 @@ class Patch:
         return f'<Patch type={self.type}, id={id(self)}>'
 
 
-@serializable.serializable_class
+@serializable.serializable_class(ignore_unknown_during_deserialization=True)
 class Pedigree:
     """
     Our internal representation of the `pedigreeType` complex type.
@@ -661,7 +661,7 @@ class Pedigree:
         return f'<Pedigree id={id(self)}, hash={hash(self)}>'
 
 
-@serializable.serializable_class
+@serializable.serializable_class(ignore_unknown_during_deserialization=True)
 class Swid:
     """
     Our internal representation of the `swidType` complex type.
@@ -813,7 +813,7 @@ class Swid:
         return f'<Swid tagId={self.tag_id}, name={self.name}, version={self.version}>'
 
 
-@serializable.serializable_class
+@serializable.serializable_class(ignore_unknown_during_deserialization=True)
 class OmniborId(serializable.helpers.BaseHelper):
     """
     Helper class that allows us to perform validation on data strings that must conform to
@@ -872,7 +872,7 @@ class OmniborId(serializable.helpers.BaseHelper):
         return self._id
 
 
-@serializable.serializable_class
+@serializable.serializable_class(ignore_unknown_during_deserialization=True)
 class Swhid(serializable.helpers.BaseHelper):
     """
     Helper class that allows us to perform validation on data strings that must conform to
@@ -931,13 +931,13 @@ class Swhid(serializable.helpers.BaseHelper):
         return self._id
 
 
-@serializable.serializable_class
+@serializable.serializable_class(ignore_unknown_during_deserialization=True)
 class Component(Dependable):
     """
     This is our internal representation of a Component within a Bom.
 
     .. note::
-        See the CycloneDX Schema definition: https://cyclonedx.org/docs/1.6/#type_component
+        See the CycloneDX Schema definition: https://cyclonedx.org/docs/1.6/xml/#type_component
     """
 
     @staticmethod
@@ -1010,11 +1010,9 @@ class Component(Dependable):
         self.supplier = supplier
         self.manufacturer = manufacturer
         self.authors = authors or []
-        self.author = author
         self.publisher = publisher
         self.group = group
         self.name = name
-        self.version = version
         self.description = description
         self.scope = scope
         self.hashes = hashes or []
@@ -1025,7 +1023,6 @@ class Component(Dependable):
         self.omnibor_ids = omnibor_ids or []
         self.swhids = swhids or []
         self.swid = swid
-        self.modified = modified
         self.pedigree = pedigree
         self.external_references = external_references or []
         self.properties = properties or []
@@ -1034,13 +1031,10 @@ class Component(Dependable):
         self.release_notes = release_notes
         self.crypto_properties = crypto_properties
         self.tags = tags or []
-
-        if modified:
-            warn('`.component.modified` is deprecated from CycloneDX v1.3 onwards. '
-                 'Please use `@.pedigree` instead.', DeprecationWarning)
-        if author:
-            warn('`.component.author` is deprecated from CycloneDX v1.6 onwards. '
-                 'Please use `@.authors` or `@.manufacturer` instead.', DeprecationWarning)
+        # spec-deprecated properties below
+        self.author = author
+        self.modified = modified
+        self.version = version
 
     @property
     @serializable.type_mapping(_ComponentTypeSerializationHelper)
@@ -1175,6 +1169,9 @@ class Component(Dependable):
 
     @author.setter
     def author(self, author: Optional[str]) -> None:
+        if author is not None:
+            warn('`@.author` is deprecated from CycloneDX v1.6 onwards. '
+                 'Please use `@.authors` or `@.manufacturer` instead.', DeprecationWarning)
         self._author = author
 
     @property
@@ -1255,7 +1252,7 @@ class Component(Dependable):
     @version.setter
     def version(self, version: Optional[str]) -> None:
         if version and len(version) > 1024:
-            warn('`.component.version`has a maximum length of 1024 from CycloneDX v1.6 onwards.', UserWarning)
+            warn('`@.version`has a maximum length of 1024 from CycloneDX v1.6 onwards.', UserWarning)
         self._version = version
 
     @property
@@ -1450,6 +1447,9 @@ class Component(Dependable):
 
     @modified.setter
     def modified(self, modified: bool) -> None:
+        if modified:
+            warn('`@.modified` is deprecated from CycloneDX v1.3 onwards. '
+                 'Please use `@.pedigree` instead.', DeprecationWarning)
         self._modified = modified
 
     @property
