@@ -1,4 +1,4 @@
-# This file is part of CycloneDX Python Lib
+# This file is part of CycloneDX Python Library
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -22,20 +22,20 @@ This set of classes represents cryptoPropertiesType Complex Type in the CycloneD
     Introduced in CycloneDX v1.6
 
 .. note::
-    See the CycloneDX Schema for hashType: https://cyclonedx.org/docs/1.6/#type_cryptoPropertiesType
+    See the CycloneDX Schema for hashType: https://cyclonedx.org/docs/1.6/xml/#type_cryptoPropertiesType
 """
 
+from collections.abc import Iterable
 from datetime import datetime
 from enum import Enum
-from typing import Any, Iterable, Optional
+from typing import Any, Optional
 
-import serializable
+import py_serializable as serializable
 from sortedcontainers import SortedSet
 
 from .._internal.compare import ComparableTuple as _ComparableTuple
 from ..exception.model import InvalidNistQuantumSecurityLevelException, InvalidRelatedCryptoMaterialSizeException
 from ..schema.schema import SchemaVersion1Dot6
-from ..serialization import BomRefHelper
 from .bom_ref import BomRef
 
 
@@ -48,7 +48,7 @@ class CryptoAssetType(str, Enum):
         Introduced in CycloneDX v1.6
 
     .. note::
-        See the CycloneDX Schema for hashType: https://cyclonedx.org/docs/1.6/#type_cryptoPropertiesType
+        See the CycloneDX Schema for hashType: https://cyclonedx.org/docs/1.6/xml/#type_cryptoPropertiesType
     """
 
     ALGORITHM = 'algorithm'
@@ -67,7 +67,7 @@ class CryptoPrimitive(str, Enum):
         Introduced in CycloneDX v1.6
 
     .. note::
-        See the CycloneDX Schema for hashType: https://cyclonedx.org/docs/1.6/#type_cryptoPropertiesType
+        See the CycloneDX Schema for hashType: https://cyclonedx.org/docs/1.6/xml/#type_cryptoPropertiesType
     """
 
     AE = 'ae'
@@ -98,7 +98,7 @@ class CryptoExecutionEnvironment(str, Enum):
         Introduced in CycloneDX v1.6
 
     .. note::
-        See the CycloneDX Schema for hashType: https://cyclonedx.org/docs/1.6/#type_cryptoPropertiesType
+        See the CycloneDX Schema for hashType: https://cyclonedx.org/docs/1.6/xml/#type_cryptoPropertiesType
     """
 
     HARDWARE = 'hardware'
@@ -120,7 +120,7 @@ class CryptoImplementationPlatform(str, Enum):
         Introduced in CycloneDX v1.6
 
     .. note::
-        See the CycloneDX Schema for hashType: https://cyclonedx.org/docs/1.6/#type_cryptoPropertiesType
+        See the CycloneDX Schema for hashType: https://cyclonedx.org/docs/1.6/xml/#type_cryptoPropertiesType
     """
 
     ARMV7_A = 'armv7-a'
@@ -150,7 +150,7 @@ class CryptoCertificationLevel(str, Enum):
         Introduced in CycloneDX v1.6
 
     .. note::
-        See the CycloneDX Schema for hashType: https://cyclonedx.org/docs/1.6/#type_cryptoPropertiesType
+        See the CycloneDX Schema for hashType: https://cyclonedx.org/docs/1.6/xml/#type_cryptoPropertiesType
     """
 
     NONE = 'none'
@@ -196,7 +196,7 @@ class CryptoMode(str, Enum):
         Introduced in CycloneDX v1.6
 
     .. note::
-        See the CycloneDX Schema for hashType: https://cyclonedx.org/docs/1.6/#type_cryptoPropertiesType
+        See the CycloneDX Schema for hashType: https://cyclonedx.org/docs/1.6/xml/#type_cryptoPropertiesType
     """
 
     CBC = 'cbc'
@@ -221,7 +221,7 @@ class CryptoPadding(str, Enum):
         Introduced in CycloneDX v1.6
 
     .. note::
-        See the CycloneDX Schema for hashType: https://cyclonedx.org/docs/1.6/#type_cryptoPropertiesType
+        See the CycloneDX Schema for hashType: https://cyclonedx.org/docs/1.6/xml/#type_cryptoPropertiesType
     """
 
     PKCS5 = 'pkcs5'
@@ -244,7 +244,7 @@ class CryptoFunction(str, Enum):
         Introduced in CycloneDX v1.6
 
     .. note::
-        See the CycloneDX Schema for hashType: https://cyclonedx.org/docs/1.6/#type_cryptoPropertiesType
+        See the CycloneDX Schema for hashType: https://cyclonedx.org/docs/1.6/xml/#type_cryptoPropertiesType
     """
 
     DECAPSULATE = 'decapsulate'
@@ -263,7 +263,7 @@ class CryptoFunction(str, Enum):
     UNKNOWN = 'unknown'
 
 
-@serializable.serializable_class
+@serializable.serializable_class(ignore_unknown_during_deserialization=True)
 class AlgorithmProperties:
     """
     This is our internal representation of the cryptoPropertiesType.algorithmProperties ENUM type within the CycloneDX
@@ -273,7 +273,7 @@ class AlgorithmProperties:
         Introduced in CycloneDX v1.6
 
     .. note::
-        See the CycloneDX Schema for hashType: https://cyclonedx.org/docs/1.6/#type_cryptoPropertiesType
+        See the CycloneDX Schema for hashType: https://cyclonedx.org/docs/1.6/xml/#type_cryptoPropertiesType
     """
 
     def __init__(
@@ -295,10 +295,10 @@ class AlgorithmProperties:
         self.curve = curve
         self.execution_environment = execution_environment
         self.implementation_platform = implementation_platform
-        self.certification_levels = certification_levels or []  # type:ignore[assignment]
+        self.certification_levels = certification_levels or []
         self.mode = mode
         self.padding = padding
-        self.crypto_functions = crypto_functions or []  # type:ignore[assignment]
+        self.crypto_functions = crypto_functions or []
         self.classical_security_level = classical_security_level
         self.nist_quantum_security_level = nist_quantum_security_level
 
@@ -322,7 +322,7 @@ class AlgorithmProperties:
         return self._primitive
 
     @primitive.setter
-    def primitive(self, primitive: CryptoPrimitive) -> None:
+    def primitive(self, primitive: Optional[CryptoPrimitive]) -> None:
         self._primitive = primitive
 
     @property
@@ -339,7 +339,7 @@ class AlgorithmProperties:
         return self._parameter_set_identifier
 
     @parameter_set_identifier.setter
-    def parameter_set_identifier(self, parameter_set_identifier: str) -> None:
+    def parameter_set_identifier(self, parameter_set_identifier: Optional[str]) -> None:
         self._parameter_set_identifier = parameter_set_identifier
 
     @property
@@ -357,7 +357,7 @@ class AlgorithmProperties:
         return self._curve
 
     @curve.setter
-    def curve(self, curve: str) -> None:
+    def curve(self, curve: Optional[str]) -> None:
         self._curve = curve
 
     @property
@@ -372,7 +372,7 @@ class AlgorithmProperties:
         return self._execution_environment
 
     @execution_environment.setter
-    def execution_environment(self, execution_environment: CryptoExecutionEnvironment) -> None:
+    def execution_environment(self, execution_environment: Optional[CryptoExecutionEnvironment]) -> None:
         self._execution_environment = execution_environment
 
     @property
@@ -388,7 +388,7 @@ class AlgorithmProperties:
         return self._implementation_platform
 
     @implementation_platform.setter
-    def implementation_platform(self, implementation_platform: CryptoImplementationPlatform) -> None:
+    def implementation_platform(self, implementation_platform: Optional[CryptoImplementationPlatform]) -> None:
         self._implementation_platform = implementation_platform
 
     @property
@@ -422,7 +422,7 @@ class AlgorithmProperties:
         return self._mode
 
     @mode.setter
-    def mode(self, mode: CryptoMode) -> None:
+    def mode(self, mode: Optional[CryptoMode]) -> None:
         self._mode = mode
 
     @property
@@ -437,7 +437,7 @@ class AlgorithmProperties:
         return self._padding
 
     @padding.setter
-    def padding(self, padding: CryptoPadding) -> None:
+    def padding(self, padding: Optional[CryptoPadding]) -> None:
         self._padding = padding
 
     @property
@@ -468,7 +468,7 @@ class AlgorithmProperties:
         return self._classical_security_level
 
     @classical_security_level.setter
-    def classical_security_level(self, classical_security_level: int) -> None:
+    def classical_security_level(self, classical_security_level: Optional[int]) -> None:
         self._classical_security_level = classical_security_level
 
     @property
@@ -485,29 +485,36 @@ class AlgorithmProperties:
         return self._nist_quantum_security_level
 
     @nist_quantum_security_level.setter
-    def nist_quantum_security_level(self, nist_quantum_security_level: int) -> None:
-        if nist_quantum_security_level < 0 or nist_quantum_security_level > 6:
+    def nist_quantum_security_level(self, nist_quantum_security_level: Optional[int]) -> None:
+        if nist_quantum_security_level is not None and (
+            nist_quantum_security_level < 0
+            or nist_quantum_security_level > 6
+        ):
             raise InvalidNistQuantumSecurityLevelException(
                 'NIST Quantum Security Level must be (0 <= value <= 6)'
             )
-
         self._nist_quantum_security_level = nist_quantum_security_level
 
+    def __comparable_tuple(self) -> _ComparableTuple:
+        return _ComparableTuple((
+            self.primitive, self._parameter_set_identifier, self.curve, self.execution_environment,
+            self.implementation_platform, _ComparableTuple(self.certification_levels), self.mode, self.padding,
+            _ComparableTuple(self.crypto_functions), self.classical_security_level, self.nist_quantum_security_level,
+        ))
+
     def __eq__(self, other: object) -> bool:
         if isinstance(other, AlgorithmProperties):
-            return hash(other) == hash(self)
+            return self.__comparable_tuple() == other.__comparable_tuple()
         return False
 
     def __hash__(self) -> int:
-        return hash((self.primitive, self._parameter_set_identifier, self.curve, self.execution_environment,
-                     self.implementation_platform, tuple(self.certification_levels), self.mode, self.padding,
-                     tuple(self.crypto_functions), self.classical_security_level, self.nist_quantum_security_level,))
+        return hash(self.__comparable_tuple())
 
     def __repr__(self) -> str:
         return f'<AlgorithmProperties primitive={self.primitive}, execution_environment={self.execution_environment}>'
 
 
-@serializable.serializable_class
+@serializable.serializable_class(ignore_unknown_during_deserialization=True)
 class CertificateProperties:
     """
     This is our internal representation of the `cryptoPropertiesType.certificateProperties` complex type within
@@ -518,7 +525,7 @@ class CertificateProperties:
 
 
     .. note::
-        See the CycloneDX Schema for hashType: https://cyclonedx.org/docs/1.6/#type_cryptoPropertiesType
+        See the CycloneDX Schema for hashType: https://cyclonedx.org/docs/1.6/xml/#type_cryptoPropertiesType
     """
 
     def __init__(
@@ -553,7 +560,7 @@ class CertificateProperties:
         return self._subject_name
 
     @subject_name.setter
-    def subject_name(self, subject_name: str) -> None:
+    def subject_name(self, subject_name: Optional[str]) -> None:
         self._subject_name = subject_name
 
     @property
@@ -584,7 +591,7 @@ class CertificateProperties:
         return self._not_valid_before
 
     @not_valid_before.setter
-    def not_valid_before(self, not_valid_before: datetime) -> None:
+    def not_valid_before(self, not_valid_before: Optional[datetime]) -> None:
         self._not_valid_before = not_valid_before
 
     @property
@@ -600,11 +607,11 @@ class CertificateProperties:
         return self._not_valid_after
 
     @not_valid_after.setter
-    def not_valid_after(self, not_valid_after: datetime) -> None:
+    def not_valid_after(self, not_valid_after: Optional[datetime]) -> None:
         self._not_valid_after = not_valid_after
 
     @property
-    @serializable.type_mapping(BomRefHelper)
+    @serializable.type_mapping(BomRef)
     @serializable.xml_sequence(50)
     def signature_algorithm_ref(self) -> Optional[BomRef]:
         """
@@ -616,11 +623,11 @@ class CertificateProperties:
         return self._signature_algorithm_ref
 
     @signature_algorithm_ref.setter
-    def signature_algorithm_ref(self, signature_algorithm_ref: BomRef) -> None:
+    def signature_algorithm_ref(self, signature_algorithm_ref: Optional[BomRef]) -> None:
         self._signature_algorithm_ref = signature_algorithm_ref
 
     @property
-    @serializable.type_mapping(BomRefHelper)
+    @serializable.type_mapping(BomRef)
     @serializable.xml_sequence(60)
     def subject_public_key_ref(self) -> Optional[BomRef]:
         """
@@ -632,7 +639,7 @@ class CertificateProperties:
         return self._subject_public_key_ref
 
     @subject_public_key_ref.setter
-    def subject_public_key_ref(self, subject_public_key_ref: BomRef) -> None:
+    def subject_public_key_ref(self, subject_public_key_ref: Optional[BomRef]) -> None:
         self._subject_public_key_ref = subject_public_key_ref
 
     @property
@@ -647,7 +654,7 @@ class CertificateProperties:
         return self._certificate_format
 
     @certificate_format.setter
-    def certificate_format(self, certificate_format: str) -> None:
+    def certificate_format(self, certificate_format: Optional[str]) -> None:
         self._certificate_format = certificate_format
 
     @property
@@ -662,17 +669,22 @@ class CertificateProperties:
         return self._certificate_extension
 
     @certificate_extension.setter
-    def certificate_extension(self, certificate_extension: str) -> None:
+    def certificate_extension(self, certificate_extension: Optional[str]) -> None:
         self._certificate_extension = certificate_extension
 
+    def __comparable_tuple(self) -> _ComparableTuple:
+        return _ComparableTuple((
+            self.subject_name, self.issuer_name, self.not_valid_before, self.not_valid_after,
+            self.certificate_format, self.certificate_extension
+        ))
+
     def __eq__(self, other: object) -> bool:
         if isinstance(other, CertificateProperties):
-            return hash(other) == hash(self)
+            return self.__comparable_tuple() == other.__comparable_tuple()
         return False
 
     def __hash__(self) -> int:
-        return hash((self.subject_name, self.issuer_name, self.not_valid_before, self.not_valid_after,
-                     self.certificate_format, self.certificate_extension))
+        return hash(self.__comparable_tuple())
 
     def __repr__(self) -> str:
         return f'<CertificateProperties subject_name={self.subject_name}, certificate_format={self.certificate_format}>'
@@ -688,7 +700,7 @@ class RelatedCryptoMaterialType(str, Enum):
         Introduced in CycloneDX v1.6
 
     .. note::
-        See the CycloneDX Schema for hashType: https://cyclonedx.org/docs/1.6/#type_cryptoPropertiesType
+        See the CycloneDX Schema for hashType: https://cyclonedx.org/docs/1.6/xml/#type_cryptoPropertiesType
     """
 
     ADDITIONAL_DATA = 'additional-data'
@@ -723,7 +735,7 @@ class RelatedCryptoMaterialState(str, Enum):
         Introduced in CycloneDX v1.6
 
     .. note::
-        See the CycloneDX Schema for hashType: https://cyclonedx.org/docs/1.6/#type_cryptoPropertiesType
+        See the CycloneDX Schema for hashType: https://cyclonedx.org/docs/1.6/xml/#type_cryptoPropertiesType
     """
 
     ACTIVE = 'active'
@@ -734,7 +746,7 @@ class RelatedCryptoMaterialState(str, Enum):
     SUSPENDED = 'suspended'
 
 
-@serializable.serializable_class
+@serializable.serializable_class(ignore_unknown_during_deserialization=True)
 class RelatedCryptoMaterialSecuredBy:
     """
     This is our internal representation of the `cryptoPropertiesType.relatedCryptoMaterialProperties.securedBy` complex
@@ -745,7 +757,7 @@ class RelatedCryptoMaterialSecuredBy:
 
 
     .. note::
-        See the CycloneDX Schema for hashType: https://cyclonedx.org/docs/1.6/#type_cryptoPropertiesType
+        See the CycloneDX Schema for hashType: https://cyclonedx.org/docs/1.6/xml/#type_cryptoPropertiesType
     """
 
     def __init__(
@@ -773,7 +785,7 @@ class RelatedCryptoMaterialSecuredBy:
         self._mechanism = mechanism
 
     @property
-    @serializable.type_mapping(BomRefHelper)
+    @serializable.type_mapping(BomRef)
     @serializable.xml_sequence(20)
     def algorithm_ref(self) -> Optional[BomRef]:
         """
@@ -788,19 +800,24 @@ class RelatedCryptoMaterialSecuredBy:
     def algorithm_ref(self, algorithm_ref: Optional[BomRef]) -> None:
         self._algorithm_ref = algorithm_ref
 
+    def __comparable_tuple(self) -> _ComparableTuple:
+        return _ComparableTuple((
+            self.mechanism, self.algorithm_ref
+        ))
+
     def __eq__(self, other: object) -> bool:
         if isinstance(other, RelatedCryptoMaterialSecuredBy):
-            return hash(other) == hash(self)
+            return self.__comparable_tuple() == other.__comparable_tuple()
         return False
 
     def __hash__(self) -> int:
-        return hash((self.mechanism, self.algorithm_ref))
+        return hash(self.__comparable_tuple())
 
     def __repr__(self) -> str:
         return f'<RelatedCryptoMaterialSecuredBy mechanism={self.mechanism}, algorithm_ref={self.algorithm_ref}>'
 
 
-@serializable.serializable_class
+@serializable.serializable_class(ignore_unknown_during_deserialization=True)
 class RelatedCryptoMaterialProperties:
     """
     This is our internal representation of the `cryptoPropertiesType.relatedCryptoMaterialProperties` complex type
@@ -811,7 +828,7 @@ class RelatedCryptoMaterialProperties:
 
 
     .. note::
-        See the CycloneDX Schema for hashType: https://cyclonedx.org/docs/1.6/#type_cryptoPropertiesType
+        See the CycloneDX Schema for hashType: https://cyclonedx.org/docs/1.6/xml/#type_cryptoPropertiesType
     """
 
     def __init__(
@@ -886,7 +903,7 @@ class RelatedCryptoMaterialProperties:
         self._state = state
 
     @property
-    @serializable.type_mapping(BomRefHelper)
+    @serializable.type_mapping(BomRef)
     @serializable.xml_sequence(40)
     def algorithm_ref(self) -> Optional[BomRef]:
         """
@@ -898,7 +915,7 @@ class RelatedCryptoMaterialProperties:
         return self._algorithm_ref
 
     @algorithm_ref.setter
-    def algorithm_ref(self, algorithm_ref: BomRef) -> None:
+    def algorithm_ref(self, algorithm_ref: Optional[BomRef]) -> None:
         self._algorithm_ref = algorithm_ref
 
     @property
@@ -1027,14 +1044,19 @@ class RelatedCryptoMaterialProperties:
     def secured_by(self, secured_by: Optional[RelatedCryptoMaterialSecuredBy]) -> None:
         self._secured_by = secured_by
 
+    def __comparable_tuple(self) -> _ComparableTuple:
+        return _ComparableTuple((
+            self.type, self.id, self.state, self.algorithm_ref, self.creation_date, self.activation_date,
+            self.update_date, self.expiration_date, self.value, self.size, self.format, self.secured_by
+        ))
+
     def __eq__(self, other: object) -> bool:
         if isinstance(other, RelatedCryptoMaterialProperties):
-            return hash(other) == hash(self)
+            return self.__comparable_tuple() == other.__comparable_tuple()
         return False
 
     def __hash__(self) -> int:
-        return hash((self.type, self.id, self.state, self.algorithm_ref, self.creation_date, self.activation_date,
-                     self.update_date, self.expiration_date, self.value, self.size, self.format, self.secured_by))
+        return hash(self.__comparable_tuple())
 
     def __repr__(self) -> str:
         return f'<RelatedCryptoMaterialProperties type={self.type}, id={self.id} state={self.state}>'
@@ -1050,7 +1072,7 @@ class ProtocolPropertiesType(str, Enum):
         Introduced in CycloneDX v1.6
 
     .. note::
-        See the CycloneDX Schema for hashType: https://cyclonedx.org/docs/1.6/#type_cryptoPropertiesType
+        See the CycloneDX Schema for hashType: https://cyclonedx.org/docs/1.6/xml/#type_cryptoPropertiesType
     """
 
     IKE = 'ike'
@@ -1064,7 +1086,7 @@ class ProtocolPropertiesType(str, Enum):
     UNKNOWN = 'unknown'
 
 
-@serializable.serializable_class
+@serializable.serializable_class(ignore_unknown_during_deserialization=True)
 class ProtocolPropertiesCipherSuite:
     """
     This is our internal representation of the `cryptoPropertiesType.protocolProperties.cipherSuites.cipherSuite`
@@ -1075,7 +1097,7 @@ class ProtocolPropertiesCipherSuite:
 
 
     .. note::
-        See the CycloneDX Schema for hashType: https://cyclonedx.org/docs/1.6/#type_cryptoPropertiesType
+        See the CycloneDX Schema for hashType: https://cyclonedx.org/docs/1.6/xml/#type_cryptoPropertiesType
     """
 
     def __init__(
@@ -1085,8 +1107,8 @@ class ProtocolPropertiesCipherSuite:
         identifiers: Optional[Iterable[str]] = None,
     ) -> None:
         self.name = name
-        self.algorithms = algorithms or []  # type:ignore[assignment]
-        self.identifiers = identifiers or []  # type:ignore[assignment]
+        self.algorithms = algorithms or []
+        self.identifiers = identifiers or []
 
     @property
     @serializable.xml_sequence(10)
@@ -1135,28 +1157,29 @@ class ProtocolPropertiesCipherSuite:
     def identifiers(self, identifiers: Iterable[str]) -> None:
         self._identifiers = SortedSet(identifiers)
 
+    def __comparable_tuple(self) -> _ComparableTuple:
+        return _ComparableTuple((
+            self.name, _ComparableTuple(self.algorithms), _ComparableTuple(self.identifiers)
+        ))
+
     def __eq__(self, other: object) -> bool:
         if isinstance(other, ProtocolPropertiesCipherSuite):
-            return hash(other) == hash(self)
+            return self.__comparable_tuple() == other.__comparable_tuple()
         return False
 
     def __lt__(self, other: Any) -> bool:
         if isinstance(other, ProtocolPropertiesCipherSuite):
-            return _ComparableTuple((
-                self.name, _ComparableTuple(self.algorithms), _ComparableTuple(self.identifiers)
-            )) < _ComparableTuple((
-                other.name, _ComparableTuple(other.algorithms), _ComparableTuple(other.identifiers)
-            ))
+            return self.__comparable_tuple() < other.__comparable_tuple()
         return NotImplemented
 
     def __hash__(self) -> int:
-        return hash((self.name, tuple(self.algorithms), tuple(self.identifiers)))
+        return hash(self.__comparable_tuple())
 
     def __repr__(self) -> str:
         return f'<ProtocolPropertiesCipherSuite name={self.name}>'
 
 
-@serializable.serializable_class
+@serializable.serializable_class(ignore_unknown_during_deserialization=True)
 class Ikev2TransformTypes:
     """
     This is our internal representation of the `cryptoPropertiesType.protocolProperties.ikev2TransformTypes`
@@ -1167,7 +1190,7 @@ class Ikev2TransformTypes:
 
 
     .. note::
-        See the CycloneDX Schema for hashType: https://cyclonedx.org/docs/1.6/#type_cryptoPropertiesType
+        See the CycloneDX Schema for hashType: https://cyclonedx.org/docs/1.6/xml/#type_cryptoPropertiesType
     """
 
     def __init__(
@@ -1179,12 +1202,12 @@ class Ikev2TransformTypes:
         esn: Optional[bool] = None,
         auth: Optional[Iterable[BomRef]] = None,
     ) -> None:
-        self.encr = encr or []  # type:ignore[assignment]
-        self.prf = prf or []  # type:ignore[assignment]
-        self.integ = integ or []  # type:ignore[assignment]
-        self.ke = ke or []  # type:ignore[assignment]
+        self.encr = encr or []
+        self.prf = prf or []
+        self.integ = integ or []
+        self.ke = ke or []
         self.esn = esn
-        self.auth = auth or []  # type:ignore[assignment]
+        self.auth = auth or []
 
     @property
     @serializable.xml_sequence(10)
@@ -1276,19 +1299,29 @@ class Ikev2TransformTypes:
     def auth(self, auth: Iterable[BomRef]) -> None:
         self._auth = SortedSet(auth)
 
+    def __comparable_tuple(self) -> _ComparableTuple:
+        return _ComparableTuple((
+            _ComparableTuple(self.encr),
+            _ComparableTuple(self.prf),
+            _ComparableTuple(self.integ),
+            _ComparableTuple(self.ke),
+            self.esn,
+            _ComparableTuple(self.auth)
+        ))
+
     def __eq__(self, other: object) -> bool:
         if isinstance(other, Ikev2TransformTypes):
-            return hash(other) == hash(self)
+            return self.__comparable_tuple() == other.__comparable_tuple()
         return False
 
     def __hash__(self) -> int:
-        return hash((tuple(self.encr), tuple(self.prf), tuple(self.integ), tuple(self.ke), self.esn, tuple(self.auth)))
+        return hash(self.__comparable_tuple())
 
     def __repr__(self) -> str:
         return f'<Ikev2TransformTypes esn={self.esn}>'
 
 
-@serializable.serializable_class
+@serializable.serializable_class(ignore_unknown_during_deserialization=True)
 class ProtocolProperties:
     """
     This is our internal representation of the `cryptoPropertiesType.protocolProperties` complex type within
@@ -1299,7 +1332,7 @@ class ProtocolProperties:
 
 
     .. note::
-        See the CycloneDX Schema for hashType: https://cyclonedx.org/docs/1.6/#type_cryptoPropertiesType
+        See the CycloneDX Schema for hashType: https://cyclonedx.org/docs/1.6/xml/#type_cryptoPropertiesType
     """
 
     def __init__(
@@ -1308,11 +1341,13 @@ class ProtocolProperties:
         version: Optional[str] = None,
         cipher_suites: Optional[Iterable[ProtocolPropertiesCipherSuite]] = None,
         ikev2_transform_types: Optional[Ikev2TransformTypes] = None,
+        crypto_refs: Optional[Iterable[BomRef]] = None,
     ) -> None:
         self.type = type
         self.version = version
-        self.cipher_suites = cipher_suites or []  # type:ignore[assignment]
+        self.cipher_suites = cipher_suites or []
         self.ikev2_transform_types = ikev2_transform_types
+        self.crypto_refs = crypto_refs or []
 
     @property
     @serializable.xml_sequence(10)
@@ -1375,19 +1410,44 @@ class ProtocolProperties:
     def ikev2_transform_types(self, ikev2_transform_types: Optional[Ikev2TransformTypes]) -> None:
         self._ikev2_transform_types = ikev2_transform_types
 
+    @property
+    @serializable.xml_array(serializable.XmlArraySerializationType.FLAT, 'cryptoRef')
+    @serializable.json_name('cryptoRefArray')
+    def crypto_refs(self) -> 'SortedSet[BomRef]':
+        """
+        A list of protocol-related cryptographic assets.
+
+        Returns:
+            `Iterable[BomRef]`
+        """
+        return self._crypto_refs
+
+    @crypto_refs.setter
+    def crypto_refs(self, crypto_refs: Iterable[BomRef]) -> None:
+        self._crypto_refs = SortedSet(crypto_refs)
+
+    def __comparable_tuple(self) -> _ComparableTuple:
+        return _ComparableTuple((
+            self.type,
+            self.version,
+            _ComparableTuple(self.cipher_suites),
+            self.ikev2_transform_types,
+            _ComparableTuple(self.crypto_refs)
+        ))
+
     def __eq__(self, other: object) -> bool:
         if isinstance(other, ProtocolProperties):
-            return hash(other) == hash(self)
+            return self.__comparable_tuple() == other.__comparable_tuple()
         return False
 
     def __hash__(self) -> int:
-        return hash((self.type, self.version, tuple(self.cipher_suites), self.ikev2_transform_types))
+        return hash(self.__comparable_tuple())
 
     def __repr__(self) -> str:
         return f'<ProtocolProperties type={self.type}, version={self.version}>'
 
 
-@serializable.serializable_class
+@serializable.serializable_class(ignore_unknown_during_deserialization=True)
 class CryptoProperties:
     """
     This is our internal representation of the `cryptoPropertiesType` complex type within CycloneDX standard.
@@ -1397,7 +1457,7 @@ class CryptoProperties:
 
 
     .. note::
-        See the CycloneDX Schema for hashType: https://cyclonedx.org/docs/1.6/#type_cryptoPropertiesType
+        See the CycloneDX Schema for hashType: https://cyclonedx.org/docs/1.6/xml/#type_cryptoPropertiesType
     """
 
     def __init__(
@@ -1476,9 +1536,10 @@ class CryptoProperties:
         return self._related_crypto_material_properties
 
     @related_crypto_material_properties.setter
-    def related_crypto_material_properties(self,
-                                           related_crypto_material_properties: Optional[RelatedCryptoMaterialProperties]
-                                           ) -> None:
+    def related_crypto_material_properties(
+        self,
+        related_crypto_material_properties: Optional[RelatedCryptoMaterialProperties]
+    ) -> None:
         self._related_crypto_material_properties = related_crypto_material_properties
 
     @property
@@ -1511,14 +1572,28 @@ class CryptoProperties:
     def oid(self, oid: Optional[str]) -> None:
         self._oid = oid
 
+    def __comparable_tuple(self) -> _ComparableTuple:
+        return _ComparableTuple((
+            self.asset_type,
+            self.algorithm_properties,
+            self.certificate_properties,
+            self.related_crypto_material_properties,
+            self.protocol_properties,
+            self.oid,
+        ))
+
     def __eq__(self, other: object) -> bool:
         if isinstance(other, CryptoProperties):
-            return hash(other) == hash(self)
+            return self.__comparable_tuple() == other.__comparable_tuple()
         return False
 
+    def __lt__(self, other: Any) -> bool:
+        if isinstance(other, CryptoProperties):
+            return self.__comparable_tuple() < other.__comparable_tuple()
+        return NotImplemented
+
     def __hash__(self) -> int:
-        return hash((self.asset_type, self.algorithm_properties, self.certificate_properties,
-                     self.related_crypto_material_properties, self.protocol_properties, self.oid))
+        return hash(self.__comparable_tuple())
 
     def __repr__(self) -> str:
         return f'<CryptoProperties asset_type={self.asset_type}, oid={self.oid}>'
