@@ -25,7 +25,7 @@ a schema extension: https://cyclonedx.org/ext/vulnerability.
 Since CycloneDX schema version 1.4, this has become part of the core schema.
 
 .. note::
-    See the CycloneDX Schema extension definition https://cyclonedx.org/docs/1.6/#type_vulnerabilitiesType
+    See the CycloneDX Schema extension definition https://cyclonedx.org/docs/1.6/xml/#type_vulnerabilitiesType
 """
 
 
@@ -55,7 +55,7 @@ from .impact_analysis import (
 from .tool import Tool, ToolRepository, _ToolRepositoryHelper
 
 
-@serializable.serializable_class
+@serializable.serializable_class(ignore_unknown_during_deserialization=True)
 class BomTargetVersionRange:
     """
     Class that represents either a version or version range and its affected status.
@@ -63,7 +63,8 @@ class BomTargetVersionRange:
     `version` and `version_range` are mutually exclusive.
 
     .. note::
-        See the CycloneDX schema: https://cyclonedx.org/docs/1.6/xml/#type_vulnerabilityType
+        See the CycloneDX schema:
+        https://cyclonedx.org/docs/1.6/json/#tab-pane_vulnerabilities_items_affects_items_versions_items_oneOf_i0
     """
 
     def __init__(
@@ -148,7 +149,7 @@ class BomTargetVersionRange:
         return f'<BomTargetVersionRange version={self.version}, version_range={self.range}, status={self.status}>'
 
 
-@serializable.serializable_class
+@serializable.serializable_class(ignore_unknown_during_deserialization=True)
 class BomTarget:
     """
     Class that represents referencing a Component or Service in a BOM.
@@ -159,7 +160,7 @@ class BomTarget:
     from a `cyclonedx.parser.BaseParser` implementation.
 
     .. note::
-        See the CycloneDX schema: https://cyclonedx.org/docs/1.6/#type_vulnerabilityType
+        See the CycloneDX schema: https://cyclonedx.org/docs/1.6/json/#vulnerabilities_items_affects
     """
 
     def __init__(
@@ -221,13 +222,13 @@ class BomTarget:
         return f'<BomTarget ref={self.ref}>'
 
 
-@serializable.serializable_class
+@serializable.serializable_class(ignore_unknown_during_deserialization=True)
 class VulnerabilityAnalysis:
     """
     Class that models the `analysis` sub-element of the `vulnerabilityType` complex type.
 
     .. note::
-        See the CycloneDX schema: https://cyclonedx.org/docs/1.6/xml/#type_vulnerabilityType
+        See the CycloneDX schema: https://cyclonedx.org/docs/1.6/json/#vulnerabilities_items_analysis
     """
 
     def __init__(
@@ -361,13 +362,13 @@ class VulnerabilityAnalysis:
         return f'<VulnerabilityAnalysis state={self.state}, justification={self.justification}>'
 
 
-@serializable.serializable_class
+@serializable.serializable_class(ignore_unknown_during_deserialization=True)
 class VulnerabilityAdvisory:
     """
     Class that models the `advisoryType` complex type.
 
     .. note::
-        See the CycloneDX schema: https://cyclonedx.org/docs/1.6/#type_advisoryType
+        See the CycloneDX schema: https://cyclonedx.org/docs/1.6/json/#vulnerabilities_items_advisories
     """
 
     def __init__(
@@ -425,7 +426,7 @@ class VulnerabilityAdvisory:
         return f'<VulnerabilityAdvisory url={self.url}, title={self.title}>'
 
 
-@serializable.serializable_class
+@serializable.serializable_class(ignore_unknown_during_deserialization=True)
 class VulnerabilitySource:
     """
     Class that models the `vulnerabilitySourceType` complex type.
@@ -433,7 +434,7 @@ class VulnerabilitySource:
     This type is used for multiple purposes in the CycloneDX schema.
 
     .. note::
-        See the CycloneDX schema: https://cyclonedx.org/docs/1.6/xml/#type_vulnerabilitySourceType
+        See the CycloneDX schema: https://cyclonedx.org/docs/1.6/json/#vulnerabilities_items_source
     """
 
     def __init__(
@@ -491,7 +492,7 @@ class VulnerabilitySource:
         return f'<VulnerabilityAdvisory name={self.name}, url={self.url}>'
 
 
-@serializable.serializable_class
+@serializable.serializable_class(ignore_unknown_during_deserialization=True)
 class VulnerabilityReference:
     """
     Class that models the nested `reference` within the `vulnerabilityType` complex type.
@@ -502,7 +503,7 @@ class VulnerabilityReference:
     intelligence.
 
     .. note::
-        See the CycloneDX schema: https://cyclonedx.org/docs/1.6/xml/#type_vulnerabilityType
+        See the CycloneDX schema: https://cyclonedx.org/docs/1.6/json/#vulnerabilities_items_references
 
     .. note::
         Properties ``id`` and ``source`` are mandatory.
@@ -582,12 +583,13 @@ class VulnerabilityScoreSource(str, Enum):
     Enum object that defines the permissible source types for a Vulnerability's score.
 
     .. note::
-        See the CycloneDX Schema definition: https://cyclonedx.org/docs/1.6/#type_scoreSourceType
+        See the CycloneDX Schema definition: https://cyclonedx.org/docs/1.6/xml/#type_scoreSourceType
 
     .. note::
         No explicit carry-over from the former schema extension:
          https://github.com/CycloneDX/specification/blob/master/schema/ext/vulnerability-1.0.xsd
     """
+
     # see `_VulnerabilityScoreSourceSerializationHelper.__CASES` for view/case map
     CVSS_V2 = 'CVSSv2'
     CVSS_V3 = 'CVSSv3'
@@ -708,7 +710,7 @@ class VulnerabilitySeverity(str, Enum):
     Class that defines the permissible severities for a Vulnerability.
 
     .. note::
-        See the CycloneDX schema: https://cyclonedx.org/docs/1.6/#type_severityType
+        See the CycloneDX schema: https://cyclonedx.org/docs/1.6/xml/#type_severityType
     """
     NONE = 'none'
     INFO = 'info'  # Only >= 1.4
@@ -753,7 +755,7 @@ class VulnerabilitySeverity(str, Enum):
             return VulnerabilitySeverity.NONE
 
 
-@serializable.serializable_class
+@serializable.serializable_class(ignore_unknown_during_deserialization=True)
 class VulnerabilityRating:
     """
     Class that models the `ratingType` complex element CycloneDX core schema.
@@ -762,7 +764,7 @@ class VulnerabilityRating:
     1.4 - see https://github.com/CycloneDX/specification/blob/master/schema/ext/vulnerability-1.0.xsd.
 
     .. note::
-        See `ratingType` in https://cyclonedx.org/docs/1.6/xml/#ratingType
+        See the CycloneDX Schema definition: https://cyclonedx.org/docs/1.6/xml/#type_ratingType
 
     .. warning::
         As part of implementing support for CycloneDX schema version 1.4, the three score types defined in the schema
@@ -891,7 +893,7 @@ class VulnerabilityRating:
             f'justification={self.justification}>'
 
 
-@serializable.serializable_class
+@serializable.serializable_class(ignore_unknown_during_deserialization=True)
 class VulnerabilityCredits:
     """
     Class that models the `credits` of `vulnerabilityType` complex type in the CycloneDX schema (version >= 1.4).
@@ -900,7 +902,7 @@ class VulnerabilityCredits:
     extension (in XML only).
 
     .. note::
-        See the CycloneDX schema: https://cyclonedx.org/docs/1.6/xml/#type_vulnerabilityType
+        See the CycloneDX schema: https://cyclonedx.org/docs/1.6/json/#vulnerabilities_items_credits
     """
 
     def __init__(
@@ -966,7 +968,7 @@ class VulnerabilityCredits:
         return f'<VulnerabilityCredits id={id(self)}>'
 
 
-@serializable.serializable_class
+@serializable.serializable_class(ignore_unknown_during_deserialization=True)
 class Vulnerability:
     """
     Class that models the `vulnerabilityType` complex type in the CycloneDX schema (version >= 1.4).
@@ -975,7 +977,7 @@ class Vulnerability:
     extension (in XML only).
 
     .. note::
-        See the CycloneDX schema: https://cyclonedx.org/docs/1.6/#type_vulnerabilityType
+        See the CycloneDX schema: https://cyclonedx.org/docs/1.6/xml/#type_vulnerabilityType
     """
 
     def __init__(
