@@ -14,9 +14,8 @@
 #
 # SPDX-License-Identifier: Apache-2.0
 # Copyright (c) OWASP Foundation. All Rights Reserved.
-
-
-from typing import Callable, Tuple
+import warnings
+from collections.abc import Callable
 from unittest import TestCase
 from uuid import uuid4
 
@@ -31,6 +30,7 @@ from cyclonedx.model.contact import OrganizationalContact, OrganizationalEntity
 from cyclonedx.model.license import DisjunctiveLicense
 from cyclonedx.model.lifecycle import LifecyclePhase, NamedLifecycle, PredefinedLifecycle
 from cyclonedx.model.tool import Tool
+from cyclonedx.output.json import JsonV1Dot6
 from tests._data.models import (
     get_bom_component_licenses_invalid,
     get_bom_component_nested_licenses_invalid,
@@ -139,6 +139,21 @@ class TestBom(TestCase):
         self.assertFalse(bom.services)
         self.assertFalse(bom.external_references)
 
+    def test_root_component_only_bom(self) -> None:
+        with warnings.catch_warnings(record=True) as w:
+            warnings.simplefilter('always')
+            bom = Bom(metadata=BomMetaData(component=Component(name='test', version='1.2')))
+            _ = JsonV1Dot6(bom).output_as_string()
+            self.assertEqual(len(w), 0)
+
+    def test_warning_missing_dependency(self) -> None:
+        with self.assertWarns(expected_warning=UserWarning) as w:
+            bom = Bom(metadata=BomMetaData(component=Component(name='root_component', version='1.2')))
+            bom.components.add(Component(name='test2', version='4.2'))
+            _ = JsonV1Dot6(bom).output_as_string()
+            self.assertEqual(len(w.warnings), 1)
+            self.assertIn('has no defined dependencies ', str(w.warnings[0]))
+
     def test_empty_bom_defined_serial(self) -> None:
         serial_number = uuid4()
         bom = Bom(serial_number=serial_number)
@@ -238,7 +253,7 @@ class TestBom(TestCase):
         ('duplicate name(k)', ((Component(name='A', bom_ref='A1'), tuple()),
                                (Component(name='A', bom_ref='A2'), tuple()))),
     )
-    def test_register_dependency(self, dependencies: Tuple[Tuple[Component, Tuple[Component, ...]], ...]) -> None:
+    def test_register_dependency(self, dependencies: tuple[tuple[Component, tuple[Component, ...]], ...]) -> None:
         bom = Bom()
         for d1, d2 in dependencies:
             bom.components.update((d1,), d2)
